@@ -1,9 +1,9 @@
 # -*- perl -*- Lintian::Index::Elf
 #
-# Copyright © 1998 Christian Schwarz
-# Copyright © 2008 Adam D. Barratt
-# Copyright © 2017-2018 Chris Lamb <lamby@debian.org>
-# Copyright © 2020 Felix Lechner
+# Copyright (C) 1998 Christian Schwarz
+# Copyright (C) 2008 Adam D. Barratt
+# Copyright (C) 2017-2018 Chris Lamb <lamby@debian.org>
+# Copyright (C) 2020-2022 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -31,8 +31,9 @@ use Cwd;
 use IPC::Run3;
 use Unicode::UTF8 qw(encode_utf8 valid_utf8 decode_utf8);
 
-use Lintian::Inspect::Elf::Section;
-use Lintian::Inspect::Elf::Symbol;
+use Lintian::Elf::Section;
+use Lintian::Elf::Symbol;
+use Lintian::Storage::MLDBM;
 
 use Moo::Role;
 use namespace::clean;
@@ -60,6 +61,40 @@ Lintian::Index::Elf binary symbol information.
 
 =over 4
 
+=item elf_storage
+
+=cut
+
+has elf_storage => (
+    is => 'rw',
+    lazy => 1,
+    default => sub {
+        my ($self) = @_;
+
+        my $storage = Lintian::Storage::MLDBM->new;
+        $storage->create('elf');
+
+        return $storage;
+    }
+);
+
+=item elf_storage_by_member
+
+=cut
+
+has elf_storage_by_member => (
+    is => 'rw',
+    lazy => 1,
+    default => sub {
+        my ($self) = @_;
+
+        my $storage = Lintian::Storage::MLDBM->new;
+        $storage->create('elf-by-member');
+
+        return $storage;
+    }
+);
+
 =item add_elf
 
 =cut
@@ -78,8 +113,8 @@ sub add_elf {
 
     # must be ELF or static library
     my @with_objects = grep {
-        $_->file_info =~ /\bELF\b/
-          || ( $_->file_info =~ /\bcurrent ar archive\b/
+        $_->file_type =~ /\bELF\b/
+          || ( $_->file_type =~ /\bcurrent ar archive\b/
             && $_->name =~ /\.a$/)
     } @files;
 
@@ -195,15 +230,6 @@ sub parse_per_file {
 
     my %by_object;
 
-    if (length $object_name) {
-
-        # object file in a static lib.
-        $file->elf_by_member->{$object_name} = \%by_object;
-
-    } else {
-        $file->elf(\%by_object);
-    }
-
     $by_object{READELF} = $from_readelf;
 
     # sometimes there are three blank lines; seen on armhf
@@ -299,7 +325,7 @@ sub parse_per_file {
         my $section_name = $section_name_by_number{$section_number}
           // $section_number;
 
-        my $symbol = Lintian::Inspect::Elf::Symbol->new;
+        my $symbol = Lintian::Elf::Symbol->new;
         $symbol->section($section_name);
         $symbol->version($symbol_version);
         $symbol->name($symbol_name);
@@ -307,6 +333,15 @@ sub parse_per_file {
         push(@{ $by_object{SYMBOLS} }, $symbol);
     }
 
+    if (length $object_name) {
+
+        # object file in a static lib.
+        $file->elf_by_member($object_name, \%by_object);
+
+    } else {
+        $file->elf(\%by_object);
+    }
+
     return;
 }
 
@@ -544,7 +579,7 @@ sub section_headers {
         }
 
         # http://sco.com/developers/gabi/latest/ch4.sheader.html
-        my $section = Lintian::Inspect::Elf::Section->new;
+        my $section = Lintian::Elf::Section->new;
         $section->number($section_header{Nr});
         $section->name($section_header{Name});
         $section->type($section_header{Type});
